==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/acl/lang/fi/lang.php <==
<?php
/**
 * Finnish language file
 *
 * @author otto@valjakko.net
 */
$lang['admin_acl']             = 'Käyttöoikeudet (ACL)';
$lang['acl_group']             = 'Ryhmä';
$lang['acl_user']              = 'Käyttäjä';
$lang['acl_perms']             = 'Oikeudet';
$lang['page']                  = 'Sivu';
$lang['namespace']             = 'Nimiavaruus';
$lang['p_user_id']             = 'Käyttäjällä <b class="acluser">%s</b> on tällä hetkellä seuraavat oikeudet sivulla <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Käyttäjällä <b class="acluser">%s</b> on tällä hetkellä seuraavat oikeudet nimiavaruudessa <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Ryhmän <b class="aclgroup">%s</b> jäsenillä on tällä hetkellä seuraavat oikeudet sivulla <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Ryhmän <b class="aclgroup">%s</b> jäsenillä on tällä hetkellä seuraavat oikeudet nimiavaruudessa <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Ole hyvä ja <b>syötä ryhmän nimi</b> yllä olevaan kaavakkeeseen katsoaksesi tai muokataksesi oikeuksia sivulle <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Ole hyvä ja <b>syötä ryhmän nimi</b> yllä olevaan kaavakkeeseen katsoaksesi tai muokataksesi oikeuksia nimiavaruuteen <b class="aclpage">%s</b>.';
$lang['p_inherited']           = 'Muomaa: Oikeuksia ei ole erikseen asetettu, vaan ne on peritty toiselta ryhmältä tai ylemmältä nimiavaruudelta.';
$lang['p_isadmin']             = 'Huomaa: Valitulla ryhmällä tai käyttäjällä on aina täydet oikeudet, koska se on määritelty pääkäyttäjäksi (Superuser)';
$lang['current']               = 'Tämänhetkiset käyttöoikeudet (ACL)';
$lang['where']                 = 'Sivu/Nimiavaruus';
$lang['who']                   = 'Käyttäjä/Ryhmä';
$lang['perm']                  = 'Oikeudet';
$lang['acl_perm0']             = 'Ei mitään';
$lang['acl_perm1']             = 'Luku';
$lang['acl_perm2']             = 'Muokkaus';
$lang['acl_perm4']             = 'Luonti';
$lang['acl_perm8']             = 'Lataus';
$lang['acl_perm16']            = 'Poisto';
$lang['acl_new']               = 'Lisää uusi';
$lang['acl_mod']               = 'Muokkaa';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/fi/lang.php <==
<?php
/**
 * Finnish language file
 *
 * @author otto@valjakko.net
 * @author Otto Vainio <otto@valjakko.net>
 */
$lang['admin_acl']             = 'Käyttöoikeudet (ACL)';
$lang['acl_group']             = 'Ryhmä';
$lang['acl_user']              = 'Käyttäjä';
$lang['acl_perms']             = 'Oikeudet';
$lang['page']                  = 'Sivu';
$lang['namespace']             = 'Nimiavaruus';
$lang['btn_select']            = 'Valitse';
$lang['p_user_id']             = 'Käyttäjällä <b class="acluser">%s</b> on tällä hetkellä seuraavat oikeudet sivulla <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Käyttäjällä <b class="acluser">%s</b> on tällä hetkellä seuraavat oikeudet nimiavaruudessa <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Ryhmän <b class="aclgroup">%s</b> jäsenillä on tällä hetkellä seuraavat oikeudet sivulla <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Ryhmän <b class="aclgroup">%s</b> jäsenillä on tällä hetkellä seuraavat oikeudet nimiavaruudessa <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Ole hyvä ja <b>syötä ryhmän nimi</b> yllä olevaan kaavakkeeseen katsoaksesi tai muokataksesi oikeuksia sivulle <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Ole hyvä ja <b>syötä ryhmän nimi</b> yllä olevaan kaavakkeeseen katsoaksesi tai muokataksesi oikeuksia nimiavaruuteen <b class="aclpage">%s</b>.';
$lang['p_inherited']           = 'Huomaa: Oikeuksia ei ole erikseen asetettu, vaan ne on peritty toiselta ryhmältä tai ylemmältä nimiavaruudelta.';
$lang['p_isadmin']             = 'Huomaa: Valitulla ryhmällä tai käyttäjällä on aina täydet oikeudet, koska se on määritelty pääkäyttäjäksi (Superuser)';
$lang['p_include']             = 'Korkeammat oikeudet sisältävät matalammat. Luonti-, Lähetys- ja Poisto-oikeudet vaikuttavat vain nimiavaruuksiin, ei sivuihin.';
$lang['current']               = 'Tämänhetkiset käyttöoikeudet (ACL)';
$lang['where']                 = 'Sivu/Nimiavaruus';
$lang['who']                   = 'Käyttäjä/Ryhmä';
$lang['perm']                  = 'Oikeudet';
$lang['acl_perm0']             = 'Ei mitään';
$lang['acl_perm1']             = 'Luku';
$lang['acl_perm2']             = 'Muokkaus';
$lang['acl_perm4']             = 'Luonti';
$lang['acl_perm8']             = 'Lähetys';
$lang['acl_perm16']            = 'Poisto';
$lang['acl_new']               = 'Lisää uusi';
$lang['acl_mod']               = 'Muokkaa';
